@@ -20,7 +20,6 @@ from kih_api.wise import wise_models
 from kih_api.wise.exceptions import MultipleUserProfilesWithSameTypeException, \
     MultipleRecipientsWithSameAccountNumberException, TransferringMoneyToNonSelfOwnedAccountsException, \
     ReserveAccountNotFoundException
-from kih_api.wise.wise_models import Quote
 
 
 class ProfileType(enum.Enum):
@@ -348,18 +347,17 @@ class Transfer:
         if not recipient.is_self_owned:
             raise TransferringMoneyToNonSelfOwnedAccountsException()
 
-        cash_account: CashAccount = CashAccount.get_by_profile_type_and_currency(api_key, profile_type, from_currency)
-        user_profile: UserProfile = UserProfile.get_by_profile_type(api_key, profile_type)
-        wise_quote: wise_models.Quote = wise_models.Quote.call(api_key, user_profile.id, from_currency.value, to_currency.value, float(receiving_amount))
-
         try:
             if from_currency == to_currency:
+                cash_account: CashAccount = CashAccount.get_by_profile_type_and_currency(api_key, profile_type, from_currency)
                 if cash_account.balance < receiving_amount:
                     raise InsufficientFundsException(f"Insufficient funds"
                                                      f"\nRequired amount: {from_currency.value} {global_common.get_formatted_string_from_decimal(receiving_amount)}"
                                                      f"\nAccount Balance: {from_currency.value} {global_common.get_formatted_string_from_decimal(cash_account.balance)}"
                                                      f"\nShort of: {from_currency.value} {global_common.get_formatted_string_from_decimal(receiving_amount - cash_account.balance)}")
 
+            user_profile: UserProfile = UserProfile.get_by_profile_type(api_key, profile_type)
+            wise_quote: wise_models.Quote = wise_models.Quote.call(api_key, user_profile.id, from_currency.value, to_currency.value, float(receiving_amount))
             wise_transfer: wise_models.Transfer = wise_models.Transfer.call(api_key, recipient.account_id, wise_quote.id, reference)
             wise_fund: wise_models.Fund = wise_models.Fund.call(api_key, user_profile.id, wise_transfer.id)
             transfer: Transfer = Transfer(user_profile, recipient, wise_transfer, wise_fund)
@@ -371,16 +369,7 @@ class Transfer:
                                                     f"\nTo: <i>{recipient.name}</i>"
                                                     f"\nReference: <i>{reference}</i>", True)
             else:
-                foreign_currency_account: CashAccount = CashAccount.get_by_profile_type_and_currency(api_key, user_profile.type, user_profile.type, to_currency)
-                receiving_amount = Decimal(str(wise_quote.targetAmount))
-                if cash_account.balance < receiving_amount:
-                    raise InsufficientFundsException(f"Insufficient funds"
-                                                     f"\nRequired amount: {from_currency.value} {global_common.get_formatted_string_from_decimal(receiving_amount)}"
-                                                     f"\nAccount Balance: {from_currency.value} {global_common.get_formatted_string_from_decimal(cash_account.balance)}"
-                                                     f"\nShort of: {from_currency.value} {global_common.get_formatted_string_from_decimal(receiving_amount - cash_account.balance)}")
-
-                IntraAccountTransfer.execute(api_key, receiving_amount, cash_account, foreign_currency_account, user_profile.type)
-                Transfer.execute(api_key, receiving_amount, recipient, foreign_currency_account.currency, to_currency, user_profile.type)
+                raise ClientErrorException(transfer.error_message)
 
             return transfer
 
